/*
 * This file is part of the Mozaïk project.
 *
 * (c) 2016 Raphaël Benitte
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

import React, { Component, PropTypes } from 'react'
import {
    ResponsiveChart as Chart,
    Scale,
    Axis,
    Grid,
    Line,
} from 'nivo'


const margin = { top: 20, right: 30, bottom: 40, left: 60 }


export default class RepoCommitActivityLineChart extends Component {
    static propTypes = {
        commits: PropTypes.array.isRequired,
    }

    static contextTypes = {
        theme: PropTypes.object.isRequired,
    }

    render() {
        const { commits } = this.props
        const { theme }   = this.context

        return (
            <Chart margin={margin} data={commits} theme={theme.charts}>
                <Scale id="commits" dataKey="total" type="linear" axis="y"/>
                <Scale id="week" dataKey="week" type="point" axis="x"/>
                <Grid yScale="commits" />
                <Axis
                    scaleId="commits"
                    position="left"
                    legend="commits"
                    legendPosition="center"
                    legendOffset={-40}
                />
                <Axis scaleId="week" axis="x" position="bottom"/>
                <Line xScale="week" x="week" yScale="commits" y="total" curve="linear"/>
            </Chart>
        )
    }
}
